@@ -1,5 +1,6 @@
 /*
     Copyright 2013 Jan Grulich <jgrulich@redhat.com>
+    Copyright 2020 Douglas Kosovic <doug@uq.edu.au>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -34,7 +35,7 @@ class L2tpPPPWidget : public QDialog
 {
     Q_OBJECT
 public:
-    explicit L2tpPPPWidget(const NetworkManager::VpnSetting::Ptr &setting, QWidget *parent = nullptr);
+    explicit L2tpPPPWidget(const NetworkManager::VpnSetting::Ptr &setting, QWidget *parent = nullptr, bool need_peer_eap = false);
     ~L2tpPPPWidget() override;
 
     NMStringMap setting() const;
@@ -42,6 +43,7 @@ public:
 private:
     void loadConfig(const NetworkManager::VpnSetting::Ptr &setting);
     Ui::L2tpPppWidget * m_ui;
+    bool m_need_peer_eap;
 };
 
 #endif // PLASMA_NM_L2TP_PPP_WIDGET_H
